==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_viewforum.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum_viewforum.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");
	
define("LAN_01", "Forums");
define("LAN_02", "Back to top");
define("LAN_03", "Go");
define("LAN_53", "Thread");
define("LAN_54", "Starter");
define("LAN_55", "Replies");
define("LAN_56", "Views");
define("LAN_57", "Latest Post");
define("LAN_58", "There are no topics in this forum yet.");
define("LAN_59", "You must be a registered member and logged in to post on this forum. Click on signup or login from the login menu.");
define("LAN_79", "New posts");
define("LAN_80", " No new posts");
define("LAN_81", "Closed thread");
define("LAN_180", "Search");
define("LAN_199", "Unread post exists");
define("LAN_202", "Sticky");
define("LAN_203", "Sticky/Closed");
define("LAN_204", "You <b>can</b> start new threads");
define("LAN_205", "You <b>cannot</b> start new threads");
define("LAN_206", "You <b>can</b> post replies");
define("LAN_207", "You <b>cannot</b> post replies");
define("LAN_208", "You <b>can</b> edit your posts");
define("LAN_209", "You <b>cannot</b> edit your posts");
define("LAN_316", "Goto page: ");
define("LAN_317", "None");
define("LAN_321", "Moderators: ");
define("LAN_395", "[popular]");
define("LAN_396", "Announcement");
	
define("LAN_397", "This forum is read only");
	
define("LAN_398", "Unstick thread");
define("LAN_399", "Lock thread");
define("LAN_400", "Unlock thread");
define("LAN_401", "Stick thread");
define("LAN_402", "Move thread");
define("LAN_403", "Jump to forum");
define("LAN_404", "This forum is moderated by");
	
define("LAN_405", "user is browsing this forum at the moment");
define("LAN_406", "users are browsing this forum at the moment");
define("LAN_407", "member");
define("LAN_408", "guest");
define("LAN_409", "members");
define("LAN_410", "guests");
	
//v.616
define("LAN_411", "Important Threads");
define("LAN_412", "Forum Threads");
define("LAN_431", "Syndicate this forum: rss 0.92");
define("LAN_432", "Syndicate this forum: rss 2.0");
define("LAN_433", "Syndicate this forum: RDF");

define("LAN_434", "Are you sure you want to delete this thread and any replies?");
define("LAN_435", "Delete thread");
	
//v.617
define("FORLAN_CLOSE", "Thread closed.");
define("FORLAN_OPEN", "Thread reopened.");
define("FORLAN_STICK", "Thread made sticky.");
define("FORLAN_UNSTICK", "Thread unstuck.");
define("FORLAN_6", "Thread deleted");
define("FORLAN_7", "replies deleted");
define("FORLAN_8", "here");
define("FORLAN_9", "to sign up or login from the login menu.");
	
define("FORLAN_10", "Begin New Thread");
define("FORLAN_11", "New Posts");
define("FORLAN_12", "No New Posts");
define("FORLAN_13", "New Posts on Popular Thread");
define("FORLAN_14", "No New Posts on Popular Thread");
define("FORLAN_15", "Sticky Thread");
define("FORLAN_16", "Closed Sticky Thread");
define("FORLAN_17", "Announcement Thread");
define("FORLAN_18", "Closed Thread");
define('FORLAN_19', '[user deleted]');
define('FORLAN_20', 'Sub-forum');
define('FORLAN_21', 'Threads');
define('FORLAN_22', 'Last Post');
	
?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_viewforum.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum_viewforum.php $
|     $Revision: 11678 $
|     $Id: lan_forum_viewforum.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");
	
define("LAN_01", "Forums");
define("LAN_02", "Back to top");
define("LAN_03", "Go");
define("LAN_53", "Thread");
define("LAN_54", "Starter");
define("LAN_55", "Replies");
define("LAN_56", "Views");
define("LAN_57", "Latest Post");
define("LAN_58", "There are no topics in this forum yet.");
define("LAN_59", "You must be a registered member and logged in to post on this forum. Click on signup or login from the login menu.");
define("LAN_79", "New posts");
define("LAN_80", " No new posts");
define("LAN_81", "Closed thread");
define("LAN_180", "Search");
define("LAN_199", "Unread post exists");
define("LAN_202", "Sticky");
define("LAN_203", "Sticky/Closed");
define("LAN_204", "You <b>can</b> start new threads");
define("LAN_205", "You <b>cannot</b> start new threads");
define("LAN_206", "You <b>can</b> post replies");
define("LAN_207", "You <b>cannot</b> post replies");
define("LAN_208", "You <b>can</b> edit your posts");
define("LAN_209", "You <b>cannot</b> edit your posts");
define("LAN_316", "Goto page: ");
define("LAN_317", "None");
define("LAN_321", "Moderators: ");
define("LAN_395", "[popular]");
define("LAN_396", "Announcement");
	
define("LAN_397", "This forum is read only");
	
define("LAN_398", "Unstick thread");
define("LAN_399", "Lock thread");
define("LAN_400", "Unlock thread");
define("LAN_401", "Stick thread");
define("LAN_402", "Move thread");
define("LAN_403", "Jump to forum");
define("LAN_404", "This forum is moderated by");
	
define("LAN_405", "user is browsing this forum at the moment");
define("LAN_406", "users are browsing this forum at the moment");
define("LAN_407", "member");
define("LAN_408", "guest");
define("LAN_409", "members");
define("LAN_410", "guests");
	
//v.616
define("LAN_411", "Important Threads");
define("LAN_412", "Forum Threads");
define("LAN_431", "Syndicate this forum: rss 0.92");
define("LAN_432", "Syndicate this forum: rss 2.0");
define("LAN_433", "Syndicate this forum: RDF");

define("LAN_434", "Are you sure you want to delete this thread and any replies?");
define("LAN_435", "Delete thread");
	
//v.617
define("FORLAN_CLOSE", "Thread closed.");
define("FORLAN_OPEN", "Thread reopened.");
define("FORLAN_STICK", "Thread made sticky.");
define("FORLAN_UNSTICK", "Thread unstuck.");
define("FORLAN_6", "Thread deleted");
define("FORLAN_7", "replies deleted");
define("FORLAN_8", "here");
define("FORLAN_9", "to sign up or login from the login menu.");
	
define("FORLAN_10", "Begin New Thread");
define("FORLAN_11", "New Posts");
define("FORLAN_12", "No New Posts");
define("FORLAN_13", "New Posts on Popular Thread");
define("FORLAN_14", "No New Posts on Popular Thread");
define("FORLAN_15", "Sticky Thread");
define("FORLAN_16", "Closed Sticky Thread");
define("FORLAN_17", "Announcement Thread");
define("FORLAN_18", "Closed Thread");
define('FORLAN_19', '[user deleted]');
define('FORLAN_20', 'Sub-forum');
define('FORLAN_21', 'Threads');
define('FORLAN_22', 'Last Post');
	
?>
